==> dokuwiki-2013.12.08.tgz: dokuwiki/lib/plugins/acl/lang/ko/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author jk Lee
 * @author dongnak@gmail.com
 * @author Song Younghwan <purluno@gmail.com>
 * @author Seung-Chul Yoo <dryoo@live.com>
 * @author erial2@gmail.com
 * @author Myeongjin <aranet100@gmail.com>
 * @author Garam <rowain8@gmail.com>
 */
$lang['admin_acl']             = '접근 제어 목록 관리';
$lang['acl_group']             = '그룹';
$lang['acl_user']              = '사용자';
$lang['acl_perms']             = '권한';
$lang['page']                  = '문서';
$lang['namespace']             = '이름공간';
$lang['btn_select']            = '선택';
$lang['p_user_id']             = '<b class="acluser">%s</b> 사용자는 현재 <b class="aclpage">%s</b>: <i>%s</i> 문서 접근이 가능합니다.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> 사용자는 현재 <b class="aclns">%s</b>: <i>%s</i> 이름공간 접근이 가능합니다.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> 그룹 구성원은 현재 <b class="aclpage">%s</b>: <i>%s</i> 문서 접근이 가능합니다.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> 그룹 구성원은 현재 <b class="aclns">%s</b>: <i>%s</i> 이름공간 접근이 가능합니다.';
$lang['p_choose_id']           = '<b class="aclpage">%s</b> 문서 접근 권한을 보거나 바꾸려면 <b>사용자</b>나 <b>그룹</b>을 위 양식에 입력하세요.';
$lang['p_choose_ns']           = '<b class="aclns">%s</b> 이름공간 접근 권한을 보거나 바꾸려면 <b>사용자</b>나 <b>그룹</b>을 위 양식에 입력하세요.';
$lang['p_inherited']           = '참고: 권한이 명시적으로 설정되지 않았으므로 다른 그룹이나 상위 이름공간으로부터 가져왔습니다.';
$lang['p_isadmin']             = '참고: 슈퍼 사용자로 설정되어 있으므로 선택된 그룹이나 사용자는 언제나 모든 접근 권한을 가집니다.';
$lang['p_include']             = '더 높은 접근 권한은 하위를 포함합니다. 문서가 아닌 이름공간에는 만들기, 올리기, 삭제 권한만 적용됩니다.';
$lang['current']               = '현재 ACL 규칙';
$lang['where']                 = '문서/이름공간';
$lang['who']                   = '사용자/그룹';
$lang['perm']                  = '접근 권한';
$lang['acl_perm0']             = '없음';
$lang['acl_perm1']             = '읽기';
$lang['acl_perm2']             = '편집';
$lang['acl_perm4']             = '만들기';
$lang['acl_perm8']             = '올리기';
$lang['acl_perm16']            = '삭제';
$lang['acl_new']               = '새 항목 추가';
$lang['acl_mod']               = '항목 수정';

==> dokuwiki-2015.08.10a.tgz: dokuwiki/lib/plugins/acl/lang/ko/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author jk Lee
 * @author dongnak@gmail.com
 * @author Song Younghwan <purluno@gmail.com>
 * @author Seung-Chul Yoo <dryoo@live.com>
 * @author erial2@gmail.com
 * @author Myeongjin <aranet100@gmail.com>
 * @author Garam <rowain8@gmail.com>
 */
$lang['admin_acl']             = '접근 제어 목록 관리';
$lang['acl_group']             = '그룹:';
$lang['acl_user']              = '사용자:';
$lang['acl_perms']             = '권한';
$lang['page']                  = '문서';
$lang['namespace']             = '이름공간';
$lang['btn_select']            = '선택';
$lang['p_user_id']             = '<b class="acluser">%s</b> 사용자는 현재 <b class="aclpage">%s</b>: <i>%s</i> 문서에 접근이 가능합니다.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> 사용자는 현재 <b class="aclns">%s</b>: <i>%s</i> 이름공간에 접근이 가능합니다.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> 그룹 구성원은 현재 <b class="aclpage">%s</b>: <i>%s</i> 문서에 접근이 가능합니다.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> 그룹 구성원은 현재 <b class="aclns">%s</b>: <i>%s</i> 이름공간에 접근이 가능합니다.';
$lang['p_choose_id']           = '<b class="aclpage">%s</b> 문서 접근 권한을 보거나 바꾸려면 <b>사용자</b>나 <b>그룹</b>을 위 양식에 입력하세요.';
$lang['p_choose_ns']           = '<b class="aclns">%s</b> 이름공간 접근 권한을 보거나 바꾸려면 <b>사용자</b>나 <b>그룹</b>을 위 양식에 입력하세요.';
$lang['p_inherited']           = '참고: 권한이 명시적으로 설정되지 않았으므로 다른 그룹이나 상위 이름공간으로부터 가져왔습니다.';
$lang['p_isadmin']             = '참고: 슈퍼 사용자로 설정되어 있으므로 선택된 그룹이나 사용자는 언제나 모든 접근 권한을 가집니다.';
$lang['p_include']             = '더 높은 접근 권한은 하위를 포함합니다. 문서가 아닌 이름공간에는 만들기, 올리기, 삭제 권한만 적용됩니다.';
$lang['current']               = '현재 ACL 규칙';
$lang['where']                 = '문서/이름공간';
$lang['who']                   = '사용자/그룹';
$lang['perm']                  = '권한';
$lang['acl_perm0']             = '없음';
$lang['acl_perm1']             = '읽기';
$lang['acl_perm2']             = '편집';
$lang['acl_perm4']             = '만들기';
$lang['acl_perm8']             = '올리기';
$lang['acl_perm16']            = '삭제';
$lang['acl_new']               = '새 항목 추가';
$lang['acl_mod']               = '항목 수정';
